@@ -8,7 +8,7 @@ Reference
 """
 import warnings
 
-from sqlalchemy.types import UserDefinedType, Integer
+from sqlalchemy.types import UserDefinedType, Integer, Float
 from sqlalchemy.sql import func
 from sqlalchemy.dialects import postgresql
 from sqlalchemy.dialects.postgresql.base import ischema_names
@@ -131,6 +131,9 @@ class _GISType(UserDefinedType):
     """ This is the way by which spatial operators are defined for
         geometry/geography columns. """
 
+    cache_ok = False
+    """ Disable cache for this type. """
+
     def __init__(self, geometry_type='GEOMETRY', srid=-1, dimension=2,
                  spatial_index=True, use_N_D_index=False, management=False, use_typmod=None,
                  from_text=None, name=None, nullable=True):
@@ -273,6 +276,9 @@ class Geometry(_GISType):
     """ The element class to use. Used by the parent class'
         ``result_processor`` method. """
 
+    cache_ok = False
+    """ Disable cache for this type. """
+
 
 class Geography(_GISType):
     """
@@ -302,6 +308,9 @@ class Geography(_GISType):
     """ The element class to use. Used by the parent class'
         ``result_processor`` method. """
 
+    cache_ok = False
+    """ Disable cache for this type. """
+
 
 class Raster(_GISType):
     """
@@ -344,6 +353,9 @@ class Raster(_GISType):
     """ The element class to use. Used by the parent class'
         ``result_processor`` method. """
 
+    cache_ok = False
+    """ Disable cache for this type. """
+
     def __init__(self, *args, **kwargs):
         # Enforce default values
         kwargs['geometry_type'] = None
@@ -370,8 +382,8 @@ class CompositeType(UserDefinedType):
             try:
                 type_ = self.type.typemap[key]
             except KeyError:
-                raise KeyError("Type '%s' doesn't have an attribute: '%s'"
-                               % (self.type, key))
+                raise AttributeError("Type '%s' doesn't have an attribute: '%s'"
+                                     % (self.type, key))
 
             return CompositeElement(self.expr, key, type_)
 
@@ -385,9 +397,27 @@ class GeometryDump(CompositeType):
     typemap = {'path': postgresql.ARRAY(Integer), 'geom': Geometry}
     """ Dictionary defining the contents of a ``geometry_dump``. """
 
+    cache_ok = True
+    """ Enable cache for this type. """
+
 
 # Register Geometry, Geography and Raster to SQLAlchemy's Postgres reflection
 # subsystem.
 ischema_names['geometry'] = Geometry
 ischema_names['geography'] = Geography
 ischema_names['raster'] = Raster
+
+
+class SummaryStats(CompositeType):
+    """Define the composite type returned by the function ST_SummaryStatsAgg"""
+    typemap = {
+        'count': Integer,
+        'sum': Float,
+        'mean': Float,
+        'stddev': Float,
+        'min': Float,
+        'max': Float,
+    }
+
+    cache_ok = True
+    """ Enable cache for this type. """
