@@ -5,10 +5,13 @@ Use CompositeType
 Some functions return composite types. This example shows how to deal with this
 kind of functions.
 """
+import pytest
+from pkg_resources import parse_version
+
+from sqlalchemy import __version__ as SA_VERSION
 from sqlalchemy import Column
 from sqlalchemy import create_engine
 from sqlalchemy import Float
-from sqlalchemy import func
 from sqlalchemy import Integer
 from sqlalchemy import MetaData
 from sqlalchemy import select
@@ -20,8 +23,8 @@ from geoalchemy2.functions import GenericFunction
 from geoalchemy2.types import CompositeType
 
 
-class SummaryStats(CompositeType):
-    """Define the composite type returned by the function ST_SummaryStatsAgg"""
+class SummaryStatsCustomType(CompositeType):
+    """Define the composite type returned by the function ST_SummaryStatsAgg."""
     typemap = {
         'count': Integer,
         'sum': Float,
@@ -31,9 +34,15 @@ class SummaryStats(CompositeType):
         'max': Float,
     }
 
+    cache_ok = True
+
 
 class ST_SummaryStatsAgg(GenericFunction):
-    type = SummaryStats
+    type = SummaryStatsCustomType
+    # Set a specific identifier to not override the actual ST_SummaryStatsAgg function
+    identifier = "ST_SummaryStatsAgg_custom"
+
+    inherit_cache = True
 
 
 engine = create_engine('postgresql://gis:gis@localhost/gis', echo=True)
@@ -62,6 +71,10 @@ class TestSTSummaryStatsAgg():
         session.rollback()
         metadata.drop_all()
 
+    @pytest.mark.skipif(
+        parse_version(SA_VERSION) < parse_version("1.4"),
+        reason="requires SQLAlchely>1.4",
+    )
     def test_st_summary_stats_agg(self):
 
         # Create a new raster
@@ -71,25 +84,27 @@ class TestSTSummaryStatsAgg():
         session.flush()
 
         # Define the query to compute stats
-        stats_agg = select([
-            func.ST_SummaryStatsAgg(Ocean.__table__.c.rast, 1, True, 1).label("stats")
-        ])
+        stats_agg = select(
+            Ocean.rast.ST_SummaryStatsAgg_custom(1, True, 1).label("stats")
+        )
         stats_agg_alias = stats_agg.alias("stats_agg")
 
         # Use these stats
-        query = select([
+        query = select(
             stats_agg_alias.c.stats.count.label("count"),
             stats_agg_alias.c.stats.sum.label("sum"),
+            stats_agg_alias.c.stats.mean.label("mean"),
             stats_agg_alias.c.stats.stddev.label("stddev"),
             stats_agg_alias.c.stats.min.label("min"),
             stats_agg_alias.c.stats.max.label("max")
-        ])
+        )
 
         # Check the query
         assert str(query) == (
             "SELECT "
             "(stats_agg.stats).count AS count, "
             "(stats_agg.stats).sum AS sum, "
+            "(stats_agg.stats).mean AS mean, "
             "(stats_agg.stats).stddev AS stddev, "
             "(stats_agg.stats).min AS min, "
             "(stats_agg.stats).max AS max \n"
@@ -106,4 +121,4 @@ class TestSTSummaryStatsAgg():
         res = session.execute(query).fetchall()
 
         # Check the result
-        assert res == [(15, 15.0, 0.0, 1.0, 1.0)]
+        assert res == [(15, 15.0, 1.0, 0.0, 1.0, 1.0)]
