@@ -80,6 +80,10 @@ class TestGeometry():
         with pytest.warns(UserWarning):
             Geometry(management=False, use_typmod=True)
 
+    def test_check_ctor_args_use_typmod_nullable(self):
+        with pytest.raises(ArgumentError):
+            Geometry(use_typmod=True, nullable=False)
+
     def test_column_expression(self, geometry_table):
         s = select([geometry_table.c.geom])
         eq_sql(s, 'SELECT ST_AsEWKB("table".geom) AS geom FROM "table"')
@@ -245,7 +249,8 @@ class TestRaster():
 class TestCompositeType():
 
     def test_ST_Dump(self, geography_table):
-        s = select([func.ST_Dump(geography_table.c.geom).geom])
+        s = select([func.ST_Dump(geography_table.c.geom).geom.label("geom")])
+
         eq_sql(s,
                'SELECT ST_AsEWKB((ST_Dump("table".geom)).geom) AS geom '
                'FROM "table"')
